Learn R Programming

NCmisc (version 1.1.5)

p.to.Z: Convert p-values to Z-scores

Description

Simple conversion of two-tailed p-values to Z-scores. Written in a way that allows maximum precision for small p-values.

Usage

p.to.Z(p)

Arguments

p

p-values (between 0 and 1), numeric, scalar, vector or matrix, or other types coercible using as.numeric()

Value

Z scores with the same dimension as the input

See Also

Z.to.p

Examples

Run this code
# NOT RUN {
p.to.Z(0.0001)
p.to.Z("5E-8")
p.to.Z(c(".05",".01",".005"))
p.to.Z(matrix(runif(16),nrow=4))
# }

Run the code above in your browser using DataLab